##  Modeling External Applications
There is often a need to model applications that your organization does not own or directly rely on but has to interface with, for example, applications of business partners, service providers, authorities, etc. In such situations, consider the following two approaches:
  * For a general view of such external applications in your architecture, create a single composite application fact sheet, for example, <External Application>, to represent all external applications. Link internal applications to this composite fact sheet through an interface to analyze dependencies and data flows in reports and diagrams. Additionally, connect to other fact sheet types to show how external applications fit into the overall architecture.
  * When external applications are crucial to your architecture, create individual application fact sheets for each one. This allows you to use all of SAP LeanIX's capabilities for detailed views and analysis. Even if you don’t own or manage these applications, they impact your architecture and business similarly to internal applications and should be treated the same way for application-based pricing.
